pub struct FscryptPolicyFlags(/* private fields */);Expand description
Flags configuring an fscrypt encryption policy.
These flags are byte-compatible with the Linux fscrypt UAPI: each member has the same value as
the corresponding FSCRYPT_POLICY_FLAG* constant in <linux/fscrypt.h>, so the flags field
of a Linux fscrypt_policy_v2 can be converted to and from this type without translation.
Implementations
Sourceimpl FscryptPolicyFlags
impl FscryptPolicyFlags
Sourcepub const PAD_8: FscryptPolicyFlags
pub const PAD_8: FscryptPolicyFlags
Pad encrypted filenames to 8-byte boundaries (when neither PAD_8 nor PAD_16 is set, filenames are padded to 4-byte boundaries; when both PAD_8 and PAD_16 are set, filenames are padded to 32-byte boundaries).
Sourcepub const PAD_16: FscryptPolicyFlags
pub const PAD_16: FscryptPolicyFlags
Pad encrypted filenames to 16-byte boundaries.
Sourcepub const DIRECT_KEY: FscryptPolicyFlags
pub const DIRECT_KEY: FscryptPolicyFlags
Use direct key mode.
Sourcepub const IV_INO_LBLK_64: FscryptPolicyFlags
pub const IV_INO_LBLK_64: FscryptPolicyFlags
Derive IVs/DUNs by hashing the inode number and combining with the 64-bit logical block
number (FSCRYPT_POLICY_FLAG_IV_INO_LBLK_64).
Sourcepub const IV_INO_LBLK_32: FscryptPolicyFlags
pub const IV_INO_LBLK_32: FscryptPolicyFlags
Derive IVs/DUNs by hashing the main key and inode number and adding the 32-bit logical
block number (FSCRYPT_POLICY_FLAG_IV_INO_LBLK_32).
Sourceimpl FscryptPolicyFlags
impl FscryptPolicyFlags
Sourcepub const fn empty() -> FscryptPolicyFlags
pub const fn empty() -> FscryptPolicyFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> FscryptPolicyFlags
pub const fn all() -> FscryptPolicyFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<FscryptPolicyFlags>
pub const fn from_bits(bits: u8) -> Option<FscryptPolicyFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> FscryptPolicyFlags
pub const fn from_bits_truncate(bits: u8) -> FscryptPolicyFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> FscryptPolicyFlags
pub const fn from_bits_retain(bits: u8) -> FscryptPolicyFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FscryptPolicyFlags>
pub fn from_name(name: &str) -> Option<FscryptPolicyFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FscryptPolicyFlags) -> bool
pub const fn intersects(&self, other: FscryptPolicyFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: FscryptPolicyFlags) -> bool
pub const fn contains(&self, other: FscryptPolicyFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: FscryptPolicyFlags)
pub fn insert(&mut self, other: FscryptPolicyFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: FscryptPolicyFlags)
pub fn remove(&mut self, other: FscryptPolicyFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FscryptPolicyFlags)
pub fn toggle(&mut self, other: FscryptPolicyFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: FscryptPolicyFlags, value: bool)
pub fn set(&mut self, other: FscryptPolicyFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
pub const fn intersection(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
pub const fn union(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
pub const fn difference(self, other: FscryptPolicyFlags) -> FscryptPolicyFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: FscryptPolicyFlags,
) -> FscryptPolicyFlags
pub const fn symmetric_difference( self, other: FscryptPolicyFlags, ) -> FscryptPolicyFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> FscryptPolicyFlags
pub const fn complement(self) -> FscryptPolicyFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl FscryptPolicyFlags
impl FscryptPolicyFlags
Sourcepub const fn iter(&self) -> Iter<FscryptPolicyFlags> ⓘ
pub const fn iter(&self) -> Iter<FscryptPolicyFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FscryptPolicyFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<FscryptPolicyFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.