OpenableLocalServerHandler

Trait OpenableLocalServerHandler 

pub trait OpenableLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn open(&mut self, request: Request<Open, ___T>) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the Openable protocol.

See Openable for more details.

Required Methods

fn open(&mut self, request: Request<Open, ___T>) -> impl Future<Output = ()>

Open (or create) a node relative to this directory. Any errors are communicated via an epitaph sent on the object channel.

Errors:

  • ZX_ERR_BAD_PATH if path is invalid
  • See Flags for other errors which may be communicated based on flags

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> OpenableLocalServerHandler<___T> for Local<___H>
where ___H: OpenableServerHandler<___T>, ___T: Transport,

Source

async fn open(&mut self, request: Request<Open, ___T>)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors